`Cura <https://cura.openrank.com>`_ is a tool to manage and grow Communities.

It gives Farcaster channels their own AI agent.
This agent helps community owners and moderators curate people and content,
manage the community wallet, distribute rewards for positive participation.
If the community wants, they can launch their own currency or token.
It's simple, intuitive and gives valuable insights to a channel moderator,
using OpenRank under the hood.
